import pygame, data

class Actor(pygame.sprite.Sprite):
    def __init__(self):
        pygame.sprite.Sprite.__init__(self)
        self.imageL = []
        self.rect = 0
        self.currentImage = None
        self._currentImage = None
        self.px=0
        self.py=0
        self.vx=0.0
        self.vy=0.0
        self.ax=0.0
        self.ay=0.0
        self.upsideDown = False
        self.gravity = -0.1
        self.airBorne = True # assume true until we collide
        self.climbing = False # are we climbing??

    def update(self):
        if self.climbing == True:
            self.py -= self.vy
            self.vy = 0
        elif self.climbing == False:
            if self.airBorne == True:
                if self.upsideDown == False:
                    self.vy-=self.ay
                    self.vy-=self.gravity
                else: # reverse gravity!
                    self.vy+=self.ay
                    self.vy+=self.gravity
                self.py+=self.vy
            self.vx+=self.ax
            self.px+=self.vx
            if self.px < 0.0:
                self.px = 0.0
            if self.py < 0:
                self.py = 0.0
            self.ax = 0.0
            self.ay = 0.0

    def draw(self, screen, camX, camY, flipX, flipY):
        screen.blit(pygame.transform.flip(self.currentImage, flipX, flipY), (self.px-camX,self.py-camY))

    def reset(self): # reset our actor
        self.px=0
        self.py=0
        self.vx=0.0
        self.vy=0.0
        self.ax=0.0
        self.ay=0.0
        self.upsideDown = False
        self.airBorne = True # assume true until we collide
        self.climbing = False # are we climbing??
        
    def getPos(self):
        return [self.px,self.py]

    def setPos(self,x,y):
        self.px = x
        self.py = y

    def setVelocityX(self,xVel):
        self.vx = xVel

    def setVelocityY(self,yVel):
        self.vy = yVel

    def setAccelX(self,xAccel):
        self.ax = xAccel

    def setAccelY(self,yAccel):
        self.ay = yAccel

    def climbUp(self, speed):
        self.vy = speed

    def climbDown(self, speed):
        self.vy = -speed

    def inFlight(self):
        return self.airBorne

    def hitFloor(self):
        self.ay = 0.0
        self.vy = 0.0
        self.airBorne = False

    def jump(self,jumpSpeed):
        if self.airBorne == False:
            self.vy = -jumpSpeed
            self.airBorne = True
                
    def releaseJump(self):
        if self.airBorne == True:
            if self.upsideDown == False:
                if self.vy < 0:
                    self.vy = self.vy * 0.8
            elif self.upsideDown == True:
                if self.vy > 0:
                    self.vy = self.vy * 0.8

    def fall(self):
        self.airBorne = True
        
    def loadSprite(self, filename, name):
        image,self.rect = data.load_image(filename,(0,255,0))
        self.imageL.append((image,name))

    def setSprite(self, name):
        for image,iname in self.imageL:
            if iname == name:
                self.currentImage = image
                self._currentImage = image
                break
